<div class="header"><?php MenuFormlet::show() ?></div>

<h1>桼Ͽ</h1>
<p>桼̾˻ȤʸȾѤαѿѤΤҤ餬ʡʡǤ<br>
ޤʸʾĹɬפǤ</p>

<?php CreateAccountFormlet::show() ?>

<p>Ͽ桼</p>

<?php AccountListFormlet::show() ?>
